aboutsummaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
Diffstat (limited to 'include')
-rw-r--r--include/sway/criteria.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/sway/criteria.h b/include/sway/criteria.h
index 1ee69a38..beb76d5f 100644
--- a/include/sway/criteria.h
+++ b/include/sway/criteria.h
@@ -73,8 +73,8 @@ struct criteria *criteria_parse(char *raw, char **error);
list_t *criteria_for_view(struct sway_view *view, enum criteria_type types);
/**
* Compile a list of views matching the given criteria.
*/
-list_t *criteria_get_views(struct criteria *criteria);
+list_t *criteria_get_containers(struct criteria *criteria);
#endif
@@ -73,8 +73,8 @@ struct criteria *criteria_parse(char *raw, char **error);
list_t *criteria_for_view(struct sway_view *view, enum criteria_type types);
/**
- * Compile a list of views matching the given criteria.
+ * Compile a list of containers matching the given criteria.
*/